using System;
using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using SimpleJSON;

namespace Frief
{

    public class BDSMPillar: MVRScript
    {
        #region PluginInfo    
        public string pluginAuthor = "Frief";
        public string pluginName = "BDSM-Pillar";
        public string pluginVersion = "1";
        public string pluginDate = "15/08" + "/2021";
        public string pluginDescription = @"Used";
        #endregion

        #region Vars    

        public JSONStorableBool SawEnabled;

        public GameObject player;
        public GameObject Ks_Fridge;

        protected JSONStorableFloat ScrubA;
        protected JSONStorableFloat ScrubB;

        private float previousValue1;
        private float previousValue2;
        private float previousValue3;

        private float maxY;
        private float minY;
        private float ScrubB_maxY;
        private float ScrubB_minY;

        private float seatX;
        private float seatY;
        private float seatZ;


        private float midY;


        private string objectNameSearchString = "Pillar";
        public Transform ObjectRoot;
        public Transform BDSMPillar_seat;
        public Transform BDSMPillar_Ancorpoint;
        public GameObject BDSMPillar_saw;


        private Renderer BDSMPillar_seatRenderer;


        private bool editorInitialized = false;
        private int initLoops = 0;
        private int maxInitLoops = 360; //3600 for one minute

        private static Atom currentAtom;
        private static string currentAtomName = "None";
        private static string tempAtomName = "None";

        #endregion

        public override void Init()
        {
            try
            {
                if (containingAtom.type != "CustomUnityAsset")
                {
                    SuperController.LogError("BDSM-Saddle: This CUA could not be initialized properly.Please select a compatible object and reload the script.");
                    return;
                }


                //**************  ScrubA
                maxY = 1.467919f;
                minY = 0.1598416f;

                ScrubA = new JSONStorableFloat("Sattle Hight", 0.7178051f, 0.130714f, 1.484664f, true);
                RegisterFloat(ScrubA);
                CreateSlider(ScrubA, false);

                //**************  ScrubB
                ScrubB_maxY = 20.47209f;
                ScrubB_minY = 0.5000364f;

                ScrubB = new JSONStorableFloat("Attachment Hight", 18.57294f, 5.000364f, 20.47209f, true);
                RegisterFloat(ScrubB);
                CreateSlider(ScrubB, false);

                SawEnabled = new JSONStorableBool("Show the Saw", true); RegisterBool(SawEnabled); CreateToggle((SawEnabled), false);

                // A tiny bit of help to give some info to your fellow creator and/or player
                JSONStorableString helpText = new JSONStorableString("Help",
                    "<color=#000><size=35><b>Help</b></size></color>\n\n" +
                    "<color=#333>" +
                    "Simple script to allow you to set the hight for for the BDSM-Sattle .\n\n" +
                    "Youn can find it under https://hub.virtamate.com/members/frief.1649 \n\n" +
                    "</color>");
                UIDynamic helpTextfield = CreateTextField(helpText, true);
                helpTextfield.height = 1100.0f;

            }
            catch (Exception e)
            {
                SuperController.LogError("Exception caught: " + e);
            }
        }

        // Update is called with each rendered frame by Unity
        void Update()
        
        {

        

            var Slider1 = ScrubA.val;
            var Slider2 = ScrubB.val;

            if (initLoops < maxInitLoops && editorInitialized == false)
            {
                initLoops++;
                InitEditor();
            }
            if (initLoops == maxInitLoops)
            {
                //SuperController.LogError("BDSMSaddle : This CUA could not be initialized properly. Please select a compatible object and reload the script.");
                initLoops++; // To avoid spamming the log with the error
            }

            if (SawEnabled.val)
            {
             BDSMPillar_saw.SetActive(true);
            }
            else
            {
              BDSMPillar_saw.SetActive(false);
            }


            if (previousValue1 != Slider1)
            {
                Slider1Changed();
            }

            if (previousValue2 != Slider2)
            {
                Slider2Changed();
            }
        }

        private bool InitEditor()
        {
            if (editorInitialized == true) return true;

            ObjectRoot = getObjectRoot(containingAtom.reParentObject);
            if (ObjectRoot == null)
            {
                return false;
            }

            BDSMPillar_seat = ObjectRoot.Find("SeatPivot");
            BDSMPillar_Ancorpoint= ObjectRoot.Find("HoldingPivit");
            BDSMPillar_saw = GameObject.Find("Pillar/SeatPivot/saw");


            seatX = BDSMPillar_seat.transform.localPosition.x;
            seatY = BDSMPillar_seat.transform.localPosition.y;
            seatZ = BDSMPillar_seat.transform.localPosition.z;

            return false;
        }

        private Transform getObjectRoot(Transform parent)
        {
            foreach (Transform child in parent)
            {
                if (child.name.Contains(objectNameSearchString))
                {
                    return child;
                }
                else
                {
                    Transform childSearch = getObjectRoot(child);
                    if (childSearch != null) return childSearch;
                }
            }

            return null;
        }

        void Slider1Changed()
        {

 //           SuperController.LogMessage("Pos:" + BDSMPillar_seat.transform.position.y);
  //         SuperController.LogMessage("Slider." + ScrubA.val);

            var Slider1 = ScrubA.val;
            var a = Slider1;

            if (BDSMPillar_seat.transform.position.y < minY)
            {
                BDSMPillar_seat.localPosition = new Vector3(seatX, minY, seatZ);
                previousValue1 = Slider1;
            }

            if (BDSMPillar_seat.transform.position.y > maxY)

            {
                BDSMPillar_seat.localPosition = new Vector3(seatX, maxY, seatZ);
                previousValue1 = Slider1;
            }

            BDSMPillar_seat.transform.localPosition = new Vector3(seatX, Slider1, seatZ);
            previousValue1 = Slider1;
        }

        void Slider2Changed()
        {

            SuperController.LogMessage("Pos:" + BDSMPillar_Ancorpoint.transform.localPosition.y);
            SuperController.LogMessage("Slider." + ScrubB.val);

            var ancor_pX = BDSMPillar_Ancorpoint.transform.localPosition.x;
            var ancor_pY = BDSMPillar_Ancorpoint.transform.localPosition.y;
            var ancor_pZ = BDSMPillar_Ancorpoint.transform.localPosition.z;
            var Slider2 = ScrubB.val;
            var a = Slider2;

            if (BDSMPillar_Ancorpoint.transform.position.y < ScrubB_minY)
            {
                BDSMPillar_Ancorpoint.localPosition = new Vector3(ancor_pX, ScrubB_minY, ancor_pZ);
                previousValue2 = Slider2;
            }


            if (BDSMPillar_Ancorpoint.transform.position.y > ScrubB_maxY)

            {
                BDSMPillar_Ancorpoint.localPosition = new Vector3(ancor_pX, ScrubB_maxY, ancor_pZ);
                previousValue2 = Slider2;
            }

            BDSMPillar_Ancorpoint.localPosition = new Vector3(ancor_pX, Slider2 / 10, ancor_pZ);
            previousValue2 = Slider2;

        }
    }
}